@@ -76,12 +76,12 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
 
     TDEAction *action;
 
-    action = new TDEAction( i18n( "Re-Populate Project" ), 0, this, TQT_SLOT( populateProject() ), actionCollection(), "repopulate_project" );
+    action = new TDEAction( i18n( "Re-Populate Project" ), 0, this, TQ_SLOT( populateProject() ), actionCollection(), "repopulate_project" );
     action->setToolTip( i18n( "Re-Populate Project" ) );
     action->setWhatsThis( i18n( "<b>Re-Populate Project</b><p>Re-Populates the project, searching through the project directory and adding all files that match one of the wildcards set in the custom manager options of the project filelist." ) );
 
     action = new TDEAction( i18n( "&Build Project" ), "make_tdevelop", Key_F8,
-                          this, TQT_SLOT( slotBuild() ),
+                          this, TQ_SLOT( slotBuild() ),
                           actionCollection(), "build_build" );
     action->setToolTip( i18n( "Build project" ) );
     action->setWhatsThis( i18n( "<b>Build project</b><p>Runs <b>make</b> from the project directory.<br>"
@@ -89,7 +89,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Build Options</b> tab." ) );
 
     action = new TDEAction( i18n( "&Build Active Directory" ), "make_tdevelop", Key_F7,
-                          this, TQT_SLOT( slotBuildActiveDir() ),
+                          this, TQ_SLOT( slotBuildActiveDir() ),
                           actionCollection(), "build_buildactivetarget" );
     action->setToolTip( i18n( "Build active directory" ) );
     action->setWhatsThis( i18n( "<b>Build active directory</b><p>Constructs a series of make commands to build the active directory. "
@@ -97,7 +97,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Make Options</b> tab." ) );
 
     action = new TDEAction( i18n( "Compile &File" ), "make_tdevelop",
-                          this, TQT_SLOT( slotCompileFile() ),
+                          this, TQ_SLOT( slotCompileFile() ),
                           actionCollection(), "build_compilefile" );
     action->setToolTip( i18n( "Compile file" ) );
     action->setWhatsThis( i18n( "<b>Compile file</b><p>Runs <b>make filename.o</b> command from the directory where 'filename' is the name of currently opened file.<br>"
@@ -105,7 +105,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Build Options</b> tab." ) );
 
     action = new TDEAction( i18n( "Install" ), 0,
-                          this, TQT_SLOT( slotInstall() ),
+                          this, TQ_SLOT( slotInstall() ),
                           actionCollection(), "build_install" );
     action->setToolTip( i18n( "Install" ) );
     action->setWhatsThis( i18n( "<b>Install</b><p>Runs <b>make install</b> command from the project directory.<br>"
@@ -113,7 +113,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Make Options</b> tab." ) );
 
     action = new TDEAction( i18n( "Install Active Directory" ), 0,
-                          this, TQT_SLOT( slotInstallActiveDir() ),
+                          this, TQ_SLOT( slotInstallActiveDir() ),
                           actionCollection(), "build_installactivetarget" );
     action->setToolTip( i18n( "Install active directory" ) );
     action->setWhatsThis( i18n( "<b>Install active directory</b><p>Runs <b>make install</b> command from the active directory.<br>"
@@ -121,7 +121,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Make Options</b> tab." ) );
 
     action = new TDEAction( i18n( "Install (as root user)" ), 0,
-                          this, TQT_SLOT( slotInstallWithKdesu() ),
+                          this, TQ_SLOT( slotInstallWithKdesu() ),
                           actionCollection(), "build_install_tdesu" );
     action->setToolTip( i18n( "Install as root user" ) );
     action->setWhatsThis( i18n( "<b>Install</b><p>Runs <b>make install</b> command from the project directory with root privileges.<br>"
@@ -130,7 +130,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Make Options</b> tab." ) );
 
     action = new TDEAction( i18n( "&Clean Project" ), 0,
-                          this, TQT_SLOT( slotClean() ),
+                          this, TQ_SLOT( slotClean() ),
                           actionCollection(), "build_clean" );
     action->setToolTip( i18n( "Clean project" ) );
     action->setWhatsThis( i18n( "<b>Clean project</b><p>Runs <b>make clean</b> command from the project directory.<br>"
@@ -138,7 +138,7 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
                                 "in the project settings dialog, <b>Build Options</b> tab." ) );
 
     action = new TDEAction( i18n( "Execute Program" ), "application-x-executable", 0,
-                          this, TQT_SLOT( slotExecute() ),
+                          this, TQ_SLOT( slotExecute() ),
                           actionCollection(), "build_execute" );
     action->setToolTip( i18n( "Execute program" ) );
     action->setWhatsThis( i18n( "<b>Execute program</b><p>Executes the main program specified in project settings, <b>Run Options</b> tab. "
@@ -162,27 +162,27 @@ CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const
             "Environment variables can be specified in the project "
             "settings dialog, <b>Build Options</b> tab." ) );
 
-    connect( m_targetMenu, TQT_SIGNAL( aboutToShow() ),
-             this, TQT_SLOT( updateTargetMenu() ) );
-    connect( m_targetMenu, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( targetMenuActivated( int ) ) );
-    connect( m_targetObjectFilesMenu, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( targetObjectFilesMenuActivated( int ) ) );
-    connect( m_targetOtherFilesMenu, TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( targetOtherFilesMenuActivated( int ) ) );
-    connect( m_makeEnvironmentsSelector->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-             this, TQT_SLOT( updateMakeEnvironmentsMenu() ) );
-    connect( m_makeEnvironmentsSelector->popupMenu(), TQT_SIGNAL( activated( int ) ),
-             this, TQT_SLOT( makeEnvironmentsMenuActivated( int ) ) );
-    connect( core(), TQT_SIGNAL( projectConfigWidget( KDialogBase* ) ),
-             this, TQT_SLOT( projectConfigWidget( KDialogBase* ) ) );
-    connect( core(), TQT_SIGNAL( contextMenu( TQPopupMenu *, const Context * ) ),
-             this, TQT_SLOT( contextMenu( TQPopupMenu *, const Context * ) ) );
+    connect( m_targetMenu, TQ_SIGNAL( aboutToShow() ),
+             this, TQ_SLOT( updateTargetMenu() ) );
+    connect( m_targetMenu, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( targetMenuActivated( int ) ) );
+    connect( m_targetObjectFilesMenu, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( targetObjectFilesMenuActivated( int ) ) );
+    connect( m_targetOtherFilesMenu, TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( targetOtherFilesMenuActivated( int ) ) );
+    connect( m_makeEnvironmentsSelector->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+             this, TQ_SLOT( updateMakeEnvironmentsMenu() ) );
+    connect( m_makeEnvironmentsSelector->popupMenu(), TQ_SIGNAL( activated( int ) ),
+             this, TQ_SLOT( makeEnvironmentsMenuActivated( int ) ) );
+    connect( core(), TQ_SIGNAL( projectConfigWidget( KDialogBase* ) ),
+             this, TQ_SLOT( projectConfigWidget( KDialogBase* ) ) );
+    connect( core(), TQ_SIGNAL( contextMenu( TQPopupMenu *, const Context * ) ),
+             this, TQ_SLOT( contextMenu( TQPopupMenu *, const Context * ) ) );
 
-    connect( makeFrontend(), TQT_SIGNAL( commandFinished( const TQString& ) ),
-             this, TQT_SLOT( slotCommandFinished( const TQString& ) ) );
-    connect( makeFrontend(), TQT_SIGNAL( commandFailed( const TQString& ) ),
-             this, TQT_SLOT( slotCommandFailed( const TQString& ) ) );
+    connect( makeFrontend(), TQ_SIGNAL( commandFinished( const TQString& ) ),
+             this, TQ_SLOT( slotCommandFinished( const TQString& ) ) );
+    connect( makeFrontend(), TQ_SIGNAL( commandFailed( const TQString& ) ),
+             this, TQ_SLOT( slotCommandFailed( const TQString& ) ) );
 }
 
 
@@ -195,26 +195,26 @@ void CustomProjectPart::projectConfigWidget( KDialogBase *dlg )
     TQVBox *vbox;
     vbox = dlg->addVBoxPage( i18n( "Custom Manager" ), i18n( "Custom Manager" ), BarIcon( "text-x-makefile", TDEIcon::SizeMedium ) );
     CustomManagerWidget *w0 = new CustomManagerWidget( this, vbox );
-    connect( dlg, TQT_SIGNAL( okClicked() ), w0, TQT_SLOT( accept() ) );
+    connect( dlg, TQ_SIGNAL( okClicked() ), w0, TQ_SLOT( accept() ) );
 
     vbox = dlg->addVBoxPage( i18n( "Run Options" ), i18n( "Run Options" ), BarIcon( "text-x-makefile", TDEIcon::SizeMedium ) );
     RunOptionsWidget *w1 = new RunOptionsWidget( *projectDom(), "/kdevcustomproject", buildDirectory(), vbox );
-    connect( dlg, TQT_SIGNAL( okClicked() ), w1, TQT_SLOT( accept() ) );
+    connect( dlg, TQ_SIGNAL( okClicked() ), w1, TQ_SLOT( accept() ) );
     vbox = dlg->addVBoxPage( i18n( "Build Options" ), i18n( "Build Options" ), BarIcon( "text-x-makefile", TDEIcon::SizeMedium ) );
     TQTabWidget *buildtab = new TQTabWidget( vbox );
 
     CustomBuildOptionsWidget *w2 = new CustomBuildOptionsWidget( *projectDom(), buildtab );
-    connect( dlg, TQT_SIGNAL( okClicked() ), w2, TQT_SLOT( accept() ) );
+    connect( dlg, TQ_SIGNAL( okClicked() ), w2, TQ_SLOT( accept() ) );
     buildtab->addTab( w2, i18n( "&Build" ) );
 
     CustomOtherConfigWidget *w4 = new CustomOtherConfigWidget( this, "/kdevcustomproject", buildtab );
-    connect( dlg, TQT_SIGNAL( okClicked() ), w4, TQT_SLOT( accept() ) );
+    connect( dlg, TQ_SIGNAL( okClicked() ), w4, TQ_SLOT( accept() ) );
     buildtab->addTab( w4, i18n( "&Other" ) );
 
     CustomMakeConfigWidget *w3 = new CustomMakeConfigWidget( this, "/kdevcustomproject", buildtab );
     buildtab->addTab( w3, i18n( "Ma&ke" ) );
     w2->setMakeOptionsWidget( buildtab, w3, w4 );
-    connect( dlg, TQT_SIGNAL( okClicked() ), w3, TQT_SLOT( accept() ) );
+    connect( dlg, TQ_SIGNAL( okClicked() ), w3, TQ_SLOT( accept() ) );
 
 }
 
@@ -241,7 +241,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         m_contextDirName = fcontext->urls().first().path();
         m_contextDirName = m_contextDirName.mid( project()->projectDirectory().length() + 1 );
         int id = popup->insertItem( i18n( "Make Active Directory" ),
-                                    this, TQT_SLOT( slotChooseActiveDirectory() ) );
+                                    this, TQ_SLOT( slotChooseActiveDirectory() ) );
         popup->setWhatsThis( id, i18n( "<b>Make active directory</b><p>"
                                        "Chooses this directory as the destination for new files created using wizards "
                                        "like the <i>New Class</i> wizard." ) );
@@ -257,7 +257,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         if ( isInBlacklist( m_contextDirName ) )
         {
             id = popup->insertItem( i18n( "Remove from blacklist" ),
-                                    this, TQT_SLOT( slotChangeBlacklist() ) );
+                                    this, TQ_SLOT( slotChangeBlacklist() ) );
             popup->setWhatsThis( id, i18n( "<b>Remove from blacklist</b><p>"
                                            "Removes the given file or directory from the "
                                            "blacklist if it is already in it.<br>The blacklist contains files and"
@@ -267,7 +267,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         else
         {
             id = popup->insertItem( i18n( "Add to blacklist" ),
-                                    this, TQT_SLOT( slotChangeBlacklist() ) );
+                                    this, TQ_SLOT( slotChangeBlacklist() ) );
             popup->setWhatsThis( id, i18n( "<b>Add to blacklist</b><p>"
                                            "Adds the given file or directory to the blacklist.<br>The blacklist contains files and"
                                            " directories that should be ignored even if they match a project filetype "
@@ -317,13 +317,13 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
     if ( m_contextAddFiles.size() > 0 )
     {
         int id = popup->insertItem( i18n( "Add Selected File/Dir(s) to Project" ),
-                                    this, TQT_SLOT( slotAddToProject() ) );
+                                    this, TQ_SLOT( slotAddToProject() ) );
         popup->setWhatsThis( id, i18n( "<b>Add to project</b><p>Adds selected file/dir(s) to the list of files in the project. "
                                        "Note that the files should be manually added to the corresponding makefile or build.xml." ) );
         if ( dirAddRecursive )
         {
             int id = popup->insertItem( i18n( "Add Selected Dir(s) to Project (recursive)" ),
-                                        this, TQT_SLOT( slotAddToProjectRecursive() ) );
+                                        this, TQ_SLOT( slotAddToProjectRecursive() ) );
             popup->setWhatsThis( id, i18n( "<b>Add to project</b><p>Recursively adds selected dir(s) to the list of files in the project. "
                                            "Note that the files should be manually added to the corresponding makefile or build.xml." ) );
         }
@@ -332,14 +332,14 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
     if ( m_contextRemoveFiles.size() > 0 )
     {
         int id = popup->insertItem( i18n( "Remove Selected File/Dir(s) From Project" ),
-                                    this, TQT_SLOT( slotRemoveFromProject() ) );
+                                    this, TQ_SLOT( slotRemoveFromProject() ) );
         popup->setWhatsThis( id, i18n( "<b>Remove from project</b><p>Removes selected file/dir(s) from the list of files in the project. "
                                        "Note that the files should be manually excluded from the corresponding makefile or build.xml." ) );
 
         if ( dirDelRecursive )
         {
             int id = popup->insertItem( i18n( "Remove Selected Dir(s) From Project (recursive)" ),
-                                        this, TQT_SLOT( slotRemoveFromProjectRecursive() ) );
+                                        this, TQ_SLOT( slotRemoveFromProjectRecursive() ) );
             popup->setWhatsThis( id, i18n( "<b>Remove from project</b><p>Recursively removes selected dir(s) from the list of files in the project. "
                                            "Note that the files should be manually excluded from the corresponding makefile or build.xml." ) );
         }
