@@ -55,9 +55,9 @@ TQRESULT DesignerInterfaceImpl::queryInterface( const TQUuid &uuid, TQUnknownInt
 {
     *iface = 0;
 
-    if ( uuid == IID_TQUnknown )
+    if ( uuid == IID_QUnknown )
 	*iface = (TQUnknownInterface*)this;
-    else if ( uuid == IID_TQComponentInformation )
+    else if ( uuid == IID_QComponentInformation )
 	*iface = (TQComponentInformationInterface*)this;
     else if ( uuid == IID_Designer )
 	*iface = (DesignerInterface*)this;
@@ -129,13 +129,13 @@ void DesignerInterfaceImpl::updateFunctionList()
 
 void DesignerInterfaceImpl::onProjectChange( TQObject *receiver, const char *slot )
 {
-    TQObject::connect( mainWindow, TQT_SIGNAL( projectChanged() ), receiver, slot );
+    TQObject::connect( mainWindow, TQ_SIGNAL( projectChanged() ), receiver, slot );
 }
 
 void DesignerInterfaceImpl::onFormChange( TQObject *receiver, const char *slot )
 {
-    TQObject::connect( mainWindow, TQT_SIGNAL( formWindowChanged() ), receiver, slot );
-    TQObject::connect( mainWindow, TQT_SIGNAL( editorChanged() ), receiver, slot );
+    TQObject::connect( mainWindow, TQ_SIGNAL( formWindowChanged() ), receiver, slot );
+    TQObject::connect( mainWindow, TQ_SIGNAL( editorChanged() ), receiver, slot );
 }
 
 bool DesignerInterfaceImpl::singleProjectMode() const
@@ -146,7 +146,7 @@ bool DesignerInterfaceImpl::singleProjectMode() const
 void DesignerInterfaceImpl::showError( TQWidget *widget,
 				       int line, const TQString &message )
 {
-    mainWindow->showErrorMessage( TQT_TQOBJECT(widget), line, message );
+    mainWindow->showErrorMessage( widget, line, message );
 }
 
 void DesignerInterfaceImpl::runFinished()
@@ -156,12 +156,12 @@ void DesignerInterfaceImpl::runFinished()
 
 void DesignerInterfaceImpl::showStackFrame( TQWidget *w, int line )
 {
-    mainWindow->showStackFrame( TQT_TQOBJECT(w), line );
+    mainWindow->showStackFrame( w, line );
 }
 
 void DesignerInterfaceImpl::showDebugStep( TQWidget *w, int line )
 {
-    mainWindow->showDebugStep( TQT_TQOBJECT(w), line );
+    mainWindow->showDebugStep( w, line );
 }
 
 void DesignerInterfaceImpl::runProjectPrecondition()
@@ -190,7 +190,7 @@ TQPtrList<DesignerFormWindow> DesignerProjectImpl::formList() const
     while ( it.current() ) {
 	TQObject *obj = it.current();
 	++it;
-	TQWidget *par = ::tqqt_cast<FormWindow*>(obj->parent());
+	TQWidget *par = ::tqt_cast<FormWindow*>(obj->parent());
 	if ( !obj->isWidgetType() || !par )
 	    continue;
 
@@ -335,7 +335,7 @@ void DesignerProjectImpl::breakPoints( TQMap<TQString, TQValueList<uint> > &bps
     for ( TQPtrListIterator<FormFile> forms = project->formFiles();
 	  forms.current(); ++forms ) {
 	if ( forms.current()->formWindow() )
-	    bps.insert( TQString( forms.current()->formWindow()->name() ) + " <Form>", MetaDataBase::breakPoints( TQT_TQOBJECT(forms.current()->formWindow()) ) );
+	    bps.insert( TQString( forms.current()->formWindow()->name() ) + " <Form>", MetaDataBase::breakPoints( forms.current()->formWindow() ) );
     }
 }
 
@@ -360,7 +360,7 @@ void DesignerProjectImpl::clearAllBreakpoints() const
     for ( TQPtrListIterator<FormFile> forms = project->formFiles();
 	  forms.current(); ++forms ) {
 	if ( forms.current()->formWindow() )
-	    MetaDataBase::setBreakPoints( TQT_TQOBJECT(forms.current()->formWindow()), empty );
+	    MetaDataBase::setBreakPoints( forms.current()->formWindow(), empty );
 	MainWindow::self->resetBreakPoints();
     }
 }
@@ -535,7 +535,7 @@ void DesignerPixmapCollectionImpl::addPixmap( const TQPixmap &p, const TQString
     pixCollection->addPixmap( pix, force );
     FormWindow *fw = MainWindow::self->formWindow();
     if ( fw )
-	MetaDataBase::setPixmapKey( TQT_TQOBJECT(fw), p.serialNumber(), name );
+	MetaDataBase::setPixmapKey( fw, p.serialNumber(), name );
 }
 
 TQPixmap DesignerPixmapCollectionImpl::pixmap( const TQString &name ) const
@@ -586,7 +586,7 @@ TQWidget *DesignerFormWindowImpl::create( const char *className, TQWidget *paren
 {
     TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( className ), parent, name );
     formWindow->insertWidget( w, TRUE );
-    formWindow->killAccels( TQT_TQOBJECT(formWindow->mainContainer()) );
+    formWindow->killAccels( formWindow->mainContainer() );
     return w;
 }
 
@@ -674,7 +674,7 @@ void DesignerFormWindowImpl::breakLayout()
 
 void DesignerFormWindowImpl::selectWidget( TQWidget * w )
 {
-    formWindow->selectWidget( TQT_TQOBJECT(w), TRUE );
+    formWindow->selectWidget( w, TRUE );
 }
 
 void DesignerFormWindowImpl::selectAll()
@@ -755,14 +755,14 @@ void DesignerFormWindowImpl::preview() const
 
 void DesignerFormWindowImpl::addConnection( TQObject *sender, const char *signal, TQObject *receiver, const char *slot )
 {
-    MetaDataBase::addConnection( TQT_TQOBJECT(formWindow), sender, signal, receiver, slot );
+    MetaDataBase::addConnection( formWindow, sender, signal, receiver, slot );
 }
 
 void DesignerFormWindowImpl::addFunction( const TQCString &function, const TQString &specifier,
 					  const TQString &access, const TQString &type,
 					  const TQString &language, const TQString &returnType )
 {
-    MetaDataBase::addFunction( TQT_TQOBJECT(formWindow), function, specifier, access, type, language, returnType );
+    MetaDataBase::addFunction( formWindow, function, specifier, access, type, language, returnType );
     formWindow->mainWindow()->functionsChanged();
 }
 
@@ -804,7 +804,7 @@ void DesignerFormWindowImpl::setColumnFields( TQObject *o, const TQMap<TQString,
 
 TQStringList DesignerFormWindowImpl::implementationIncludes() const
 {
-    TQValueList<MetaDataBase::Include> includes = MetaDataBase::includes( TQT_TQOBJECT(formWindow) );
+    TQValueList<MetaDataBase::Include> includes = MetaDataBase::includes( formWindow );
     TQStringList lst;
     for ( TQValueList<MetaDataBase::Include>::Iterator it = includes.begin(); it != includes.end(); ++it ) {
 	MetaDataBase::Include inc = *it;
@@ -825,7 +825,7 @@ TQStringList DesignerFormWindowImpl::implementationIncludes() const
 
 TQStringList DesignerFormWindowImpl::declarationIncludes() const
 {
-    TQValueList<MetaDataBase::Include> includes = MetaDataBase::includes( TQT_TQOBJECT(formWindow) );
+    TQValueList<MetaDataBase::Include> includes = MetaDataBase::includes( formWindow );
     TQStringList lst;
     for ( TQValueList<MetaDataBase::Include>::Iterator it = includes.begin(); it != includes.end(); ++it ) {
 	MetaDataBase::Include inc = *it;
@@ -846,7 +846,7 @@ TQStringList DesignerFormWindowImpl::declarationIncludes() const
 
 void DesignerFormWindowImpl::setImplementationIncludes( const TQStringList &lst )
 {
-    TQValueList<MetaDataBase::Include> oldIncludes = MetaDataBase::includes( TQT_TQOBJECT(formWindow) );
+    TQValueList<MetaDataBase::Include> oldIncludes = MetaDataBase::includes( formWindow );
     TQValueList<MetaDataBase::Include> includes;
     for ( TQValueList<MetaDataBase::Include>::Iterator it = oldIncludes.begin(); it != oldIncludes.end(); ++it ) {
 	MetaDataBase::Include inc = *it;
@@ -882,13 +882,13 @@ void DesignerFormWindowImpl::setImplementationIncludes( const TQStringList &lst
 	    includes << inc;
 	}
     }
-    MetaDataBase::setIncludes( TQT_TQOBJECT(formWindow), includes );
+    MetaDataBase::setIncludes( formWindow, includes );
     formWindow->mainWindow()->objectHierarchy()->formDefinitionView()->setup();
 }
 
 void DesignerFormWindowImpl::setDeclarationIncludes( const TQStringList &lst )
 {
-    TQValueList<MetaDataBase::Include> oldIncludes = MetaDataBase::includes( TQT_TQOBJECT(formWindow) );
+    TQValueList<MetaDataBase::Include> oldIncludes = MetaDataBase::includes( formWindow );
     TQValueList<MetaDataBase::Include> includes;
     for ( TQValueList<MetaDataBase::Include>::Iterator it = oldIncludes.begin(); it != oldIncludes.end(); ++it ) {
 	MetaDataBase::Include inc = *it;
@@ -924,60 +924,60 @@ void DesignerFormWindowImpl::setDeclarationIncludes( const TQStringList &lst )
 	    includes << inc;
 	}
     }
-    MetaDataBase::setIncludes( TQT_TQOBJECT(formWindow), includes );
+    MetaDataBase::setIncludes( formWindow, includes );
     formWindow->mainWindow()->objectHierarchy()->formDefinitionView()->setup();
 }
 
 TQStringList DesignerFormWindowImpl::forwardDeclarations() const
 {
-    return MetaDataBase::forwards( TQT_TQOBJECT(formWindow) );
+    return MetaDataBase::forwards( formWindow );
 }
 
 void DesignerFormWindowImpl::setForwardDeclarations( const TQStringList &lst )
 {
-    MetaDataBase::setForwards( TQT_TQOBJECT(formWindow), lst );
+    MetaDataBase::setForwards( formWindow, lst );
     formWindow->mainWindow()->objectHierarchy()->formDefinitionView()->setup();
 }
 
 TQStringList DesignerFormWindowImpl::signalList() const
 {
-    return MetaDataBase::signalList( TQT_TQOBJECT(formWindow) );
+    return MetaDataBase::signalList( formWindow );
 }
 
 void DesignerFormWindowImpl::setSignalList( const TQStringList &lst )
 {
-    MetaDataBase::setSignalList( TQT_TQOBJECT(formWindow), lst );
+    MetaDataBase::setSignalList( formWindow, lst );
     formWindow->mainWindow()->objectHierarchy()->formDefinitionView()->setup();
 }
 
 void DesignerFormWindowImpl::onModificationChange( TQObject *receiver, const char *slot )
 {
-    TQObject::connect( formWindow, TQT_SIGNAL( modificationChanged( bool, FormWindow * ) ), receiver, slot );
+    TQObject::connect( formWindow, TQ_SIGNAL( modificationChanged( bool, FormWindow * ) ), receiver, slot );
 }
 
 void DesignerFormWindowImpl::addMenu( const TQString &text, const TQString &name )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
 
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     PopupMenuEditor *popup = new PopupMenuEditor( formWindow, mw );
     TQString n = name;
-    formWindow->unify(  TQT_TQOBJECT(popup), n, TRUE );
+    formWindow->unify(  popup, n, TRUE );
     popup->setName( n );
     MenuBarEditor *mb = (MenuBarEditor *)mw->child( 0, "MenuBarEditor" );
     if ( !mb ) {
 	mb = new MenuBarEditor( formWindow, mw );
 	mb->setName( "MenuBar" );
-	MetaDataBase::addEntry( TQT_TQOBJECT(mb) );
+	MetaDataBase::addEntry( mb );
     }
     mb->insertItem( text, popup );
-    MetaDataBase::addEntry( TQT_TQOBJECT(popup) );
+    MetaDataBase::addEntry( popup );
 }
 
 void DesignerFormWindowImpl::addMenuAction( const TQString &menu, TQAction *a )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     if ( !mw->child( 0, "MenuBarEditor" ) )
@@ -990,7 +990,7 @@ void DesignerFormWindowImpl::addMenuAction( const TQString &menu, TQAction *a )
 
 void DesignerFormWindowImpl::addMenuSeparator( const TQString &menu )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     if ( !mw->child( 0, "MenuBarEditor" ) )
@@ -1004,19 +1004,19 @@ void DesignerFormWindowImpl::addMenuSeparator( const TQString &menu )
 
 void DesignerFormWindowImpl::addToolBar( const TQString &text, const TQString &name )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     TQToolBar *tb = new QDesignerToolBar( mw );
     TQString n = name;
-    formWindow->unify(  TQT_TQOBJECT(tb), n, TRUE );
+    formWindow->unify(  tb, n, TRUE );
     tb->setName( n );
     mw->addToolBar( tb, text );
 }
 
 void DesignerFormWindowImpl::addToolBarAction( const TQString &tbn, TQAction *a )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     QDesignerToolBar *tb = (QDesignerToolBar*)mw->child( tbn, "QDesignerToolBar" );
@@ -1028,7 +1028,7 @@ void DesignerFormWindowImpl::addToolBarAction( const TQString &tbn, TQAction *a
 
 void DesignerFormWindowImpl::addToolBarSeparator( const TQString &tbn )
 {
-    if ( !::tqqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
+    if ( !::tqt_cast<TQMainWindow*>(formWindow->mainContainer()) )
 	return;
     TQMainWindow *mw = (TQMainWindow*)formWindow->mainContainer();
     QDesignerToolBar *tb = (QDesignerToolBar*)mw->child( tbn, "QDesignerToolBar" );
