@@ -77,7 +77,7 @@ void FormItem::insert( Project *pro )
     FormFile *ff = new FormFile( FormFile::createUnnamedFileName(), TRUE, pro );
     fw = new FormWindow( ff, MainWindow::self, MainWindow::self->qWorkspace(), n );
     fw->setProject( pro );
-    MetaDataBase::addEntry( TQT_TQOBJECT(fw) );
+    MetaDataBase::addEntry( fw );
     if ( fType == Widget ) {
 	TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQWidget" ),
 					    fw, n.latin1() );
@@ -109,10 +109,10 @@ void FormItem::insert( Project *pro )
 
     // the wizard might have changed a lot, lets update everything
     MainWindow::self->actioneditor()->setFormWindow( fw );
-    MainWindow::self->objectHierarchy()->setFormWindow( fw, TQT_TQOBJECT(fw) );
+    MainWindow::self->objectHierarchy()->setFormWindow( fw, fw );
     MainWindow::self->objectHierarchy()->formDefinitionView()->refresh();
     MainWindow::self->objectHierarchy()->rebuild();
-    fw->killAccels( TQT_TQOBJECT(fw) );
+    fw->killAccels( fw );
     fw->project()->setModified( TRUE );
     fw->setFocus();
     if ( !pro->isDummy() ) {
@@ -368,7 +368,7 @@ NewForm::NewForm( TQWidget *parent, const TQStringList& projects,
 		  const TQString& currentProject, const TQString &templatePath )
     : NewFormBase( parent, 0, TRUE )
 {
-    connect( helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
+    connect( helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
 
     projectCombo->insertStringList( projects );
     projectCombo->setCurrentText( currentProject );
