@@ -1066,7 +1066,7 @@ TQObjectList *Project::formList( bool resolveFakeObjects ) const
 	    if ( resolveFakeObjects && f->formWindow()->isFake() )
 		l->append( objectForFakeForm( f->formWindow() ) );
 	    else
-		l->append( f->formWindow()->child( 0, TQWIDGET_OBJECT_NAME_STRING ) );
+		l->append( f->formWindow()->child( 0, "TQWidget" ) );
 	} else if ( f->isFake() ) {
 	    l->append( objectForFakeFormFile( f ) );
 	}
@@ -1311,9 +1311,9 @@ void Project::addObject( TQObject *o )
 	if ( MainWindow::self ) {
 	    TQApplication::sendPostedEvents( MainWindow::self->qWorkspace(), TQEvent::ChildInserted );
 	    connect( fw,
-		     TQT_SIGNAL( undoRedoChanged( bool, bool, const TQString &, const TQString & ) ),
+		     TQ_SIGNAL( undoRedoChanged( bool, bool, const TQString &, const TQString & ) ),
 		     MainWindow::self,
-		     TQT_SLOT( updateUndoRedo( bool, bool, const TQString &, const TQString & ) )
+		     TQ_SLOT( updateUndoRedo( bool, bool, const TQString &, const TQString & ) )
 		);
 	}
 	if ( fw->parentWidget() ) {
@@ -1487,9 +1487,9 @@ void Project::designerCreated()
 	if ( !fw || fw->mainWindow() )
 	    continue;
 	fw->setMainWindow( MainWindow::self );
-	connect( fw, TQT_SIGNAL( undoRedoChanged( bool, bool, const TQString &,
+	connect( fw, TQ_SIGNAL( undoRedoChanged( bool, bool, const TQString &,
 					      const TQString & ) ),
-		 MainWindow::self, TQT_SLOT( updateUndoRedo( bool, bool,
+		 MainWindow::self, TQ_SLOT( updateUndoRedo( bool, bool,
 					 const TQString &, const TQString & ) ) );
 	fw->reparent( MainWindow::self->qWorkspace(), TQPoint( 0, 0 ), FALSE );
 	TQApplication::sendPostedEvents( MainWindow::self->qWorkspace(),
@@ -1514,8 +1514,8 @@ TQString Project::locationOfObject( TQObject *o )
     if ( MainWindow::self ) {
 	TQWidgetList windows = MainWindow::self->qWorkspace()->windowList();
 	for ( TQWidget *w = windows.first(); w; w = windows.next() ) {
-	    FormWindow *fw = ::tqqt_cast<FormWindow*>(w);
-	    SourceEditor *se = ::tqqt_cast<SourceEditor*>(w);
+	    FormWindow *fw = ::tqt_cast<FormWindow*>(w);
+	    SourceEditor *se = ::tqt_cast<SourceEditor*>(w);
 	    if ( fw ) {
 		if ( fw->isFake() )
 		    return objectForFakeForm( fw )->name() + TQString( " [Source]" );
@@ -1532,7 +1532,7 @@ TQString Project::locationOfObject( TQObject *o )
 	}
     }
 
-    if ( ::tqqt_cast<SourceFile*>(o) ) {
+    if ( ::tqt_cast<SourceFile*>(o) ) {
 	for ( TQPtrListIterator<SourceFile> sources = sourceFiles();
 	      sources.current(); ++sources ) {
 	    SourceFile* f = sources.current();
