@@ -112,7 +112,7 @@ private:
 
 class CppNewClassDialog : public CppNewClassDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
