@@ -66,11 +66,11 @@
 
 using namespace std;
 
-static const KDevPluginInfo data("kdevphpsupport");
-K_EXPORT_COMPONENT_FACTORY( libkdevphpsupport, PHPSupportFactory( data ) )
+static const KDevPluginInfo pluginData("kdevphpsupport");
+K_EXPORT_COMPONENT_FACTORY( libkdevphpsupport, PHPSupportFactory( pluginData ) )
 
 PHPSupportPart::PHPSupportPart(TQObject *parent, const char *name, const TQStringList &)
-    : KDevLanguageSupport(&data, parent, name ? name : "PHPSupportPart")
+    : KDevLanguageSupport(&pluginData, parent, name ? name : "PHPSupportPart")
 {
    m_htmlView = 0;
    m_parser = 0;
@@ -79,23 +79,23 @@ PHPSupportPart::PHPSupportPart(TQObject *parent, const char *name, const TQStrin
 
    setXMLFile("kdevphpsupport.rc");
 
-   connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()) );
-   connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()) );
-   connect( partController(), TQT_SIGNAL(savedFile(const KURL&)),
-            this, TQT_SLOT(savedFile(const KURL&)) );
-   connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
-            this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
+   connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()) );
+   connect( core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()) );
+   connect( partController(), TQ_SIGNAL(savedFile(const KURL&)),
+            this, TQ_SLOT(savedFile(const KURL&)) );
+   connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)),
+            this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
 
    TDEAction *action;
 
    action = new TDEAction( i18n("&Run"), "application-x-executable",Key_F9,
-   this, TQT_SLOT(slotRun()),
+   this, TQ_SLOT(slotRun()),
    actionCollection(), "build_execute" );
    action->setToolTip(i18n("Run"));
    action->setWhatsThis(i18n("<b>Run</b><p>Executes script on a terminal or a webserver."));
 
    action = new TDEAction( i18n("&New Class..."),0,
-   this, TQT_SLOT(slotNewClass()),
+   this, TQ_SLOT(slotNewClass()),
    actionCollection(), "project_new_class" );
    action->setToolTip(i18n("New class"));
    action->setWhatsThis(i18n("<b>New class</b><p>Runs New Class wizard."));
@@ -107,29 +107,29 @@ PHPSupportPart::PHPSupportPart(TQObject *parent, const char *name, const TQStrin
    mainWindow()->embedOutputView(m_phpErrorView, i18n("Problems"), i18n("Problems"));
 
    phpExeProc = new KShellProcess("/bin/sh");
-   connect( phpExeProc, TQT_SIGNAL(receivedStdout (TDEProcess*, char*, int)),
-            this, TQT_SLOT(slotReceivedPHPExeStdout (TDEProcess*, char*, int)));
-   connect( phpExeProc, TQT_SIGNAL(receivedStderr (TDEProcess*, char*, int)),
-            this, TQT_SLOT(slotReceivedPHPExeStderr (TDEProcess*, char*, int)));
-   connect( phpExeProc, TQT_SIGNAL(processExited(TDEProcess*)),
-            this, TQT_SLOT(slotPHPExeExited(TDEProcess*)));
+   connect( phpExeProc, TQ_SIGNAL(receivedStdout (TDEProcess*, char*, int)),
+            this, TQ_SLOT(slotReceivedPHPExeStdout (TDEProcess*, char*, int)));
+   connect( phpExeProc, TQ_SIGNAL(receivedStderr (TDEProcess*, char*, int)),
+            this, TQ_SLOT(slotReceivedPHPExeStderr (TDEProcess*, char*, int)));
+   connect( phpExeProc, TQ_SIGNAL(processExited(TDEProcess*)),
+            this, TQ_SLOT(slotPHPExeExited(TDEProcess*)));
 
    m_htmlView = new PHPHTMLView(this);
    mainWindow()->embedOutputView(m_htmlView->view(), i18n("PHP"), i18n("PHP"));
-   connect( m_htmlView,  TQT_SIGNAL(started(TDEIO::Job*)),
-            this, TQT_SLOT(slotWebJobStarted(TDEIO::Job*)));
+   connect( m_htmlView,  TQ_SIGNAL(started(TDEIO::Job*)),
+            this, TQ_SLOT(slotWebJobStarted(TDEIO::Job*)));
 
    configData = new PHPConfigData(projectDom());
-   connect( configData,  TQT_SIGNAL(configStored()),
-            this, TQT_SLOT(slotConfigStored()));
+   connect( configData,  TQ_SIGNAL(configStored()),
+            this, TQ_SLOT(slotConfigStored()));
 
    m_codeCompletion = new  PHPCodeCompletion(this, configData);
 
-   new TDEAction(i18n("Complete Text"), CTRL+Key_Space, m_codeCompletion, TQT_SLOT(cursorPositionChanged()), actionCollection(), "edit_complete_text");
+   new TDEAction(i18n("Complete Text"), CTRL+Key_Space, m_codeCompletion, TQ_SLOT(cursorPositionChanged()), actionCollection(), "edit_complete_text");
 
-   connect( partController(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
-            this, TQT_SLOT(slotActivePartChanged(KParts::Part *)));
-   connect( this, TQT_SIGNAL(fileParsed( PHPFile* )), this, TQT_SLOT(slotfileParsed( PHPFile* )));
+   connect( partController(), TQ_SIGNAL(activePartChanged(KParts::Part*)),
+            this, TQ_SLOT(slotActivePartChanged(KParts::Part *)));
+   connect( this, TQ_SIGNAL(fileParsed( PHPFile* )), this, TQ_SLOT(slotfileParsed( PHPFile* )));
 }
 
 PHPSupportPart::~PHPSupportPart()
@@ -180,7 +180,7 @@ void PHPSupportPart::slotActivePartChanged(KParts::Part *part) {
    if (m_editInterface) { // connect to the editor
       disconnect(part, 0, this, 0 ); // to make sure that it is't connected twice
       if (configData->getRealtimeParsing()) {
-         connect(part,TQT_SIGNAL(textChanged()),this,TQT_SLOT(slotTextChanged()));
+         connect(part,TQ_SIGNAL(textChanged()),this,TQ_SLOT(slotTextChanged()));
       }
       m_codeCompletion->setActiveEditorPart(part);
    }
@@ -210,7 +210,7 @@ void PHPSupportPart::slotConfigStored() {
 void PHPSupportPart::projectConfigWidget(KDialogBase *dlg) {
    TQVBox *vbox = dlg->addVBoxPage(i18n( "PHP Specific" ), i18n("PHP Settings"), BarIcon( "text-x-src", TDEIcon::SizeMedium ));
    PHPConfigWidget* w = new PHPConfigWidget(configData,vbox, "php config widget");
-   connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+   connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
 }
 
 void PHPSupportPart::slotNewClass() {
@@ -242,7 +242,7 @@ bool PHPSupportPart::validateConfig() {
 
       TQVBox *vbox = dlg.addVBoxPage(i18n("PHP Settings"));
       PHPConfigWidget* w = new PHPConfigWidget(configData,vbox, "php config widget");
-      connect( &dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+      connect( &dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
       dlg.exec();
    }
    if (configData->validateConfig()) {
@@ -298,10 +298,10 @@ void PHPSupportPart::slotWebJobStarted(TDEIO::Job* job) {
    if (job && job->className() == TQString("TDEIO::TransferJob")) {
       kdDebug(9018) << endl << "job started" << job->progressId();
       TDEIO::TransferJob *tjob = static_cast<TDEIO::TransferJob*>(job);
-      connect( tjob,  TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-               this, TQT_SLOT(slotWebData(TDEIO::Job*, const TQByteArray&)));
-      connect( tjob,  TQT_SIGNAL(result(TDEIO::Job*)),
-               this, TQT_SLOT(slotWebResult(TDEIO::Job*)));
+      connect( tjob,  TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+               this, TQ_SLOT(slotWebData(TDEIO::Job*, const TQByteArray&)));
+      connect( tjob,  TQ_SIGNAL(result(TDEIO::Job*)),
+               this, TQ_SLOT(slotWebResult(TDEIO::Job*)));
    }
 }
 
@@ -381,10 +381,10 @@ void PHPSupportPart::projectOpened()
 {
     kdDebug(9018) << "projectOpened()" << endl;
 
-    connect( project(), TQT_SIGNAL(addedFilesToProject(const TQStringList &)),
-             this, TQT_SLOT(addedFilesToProject(const TQStringList &)) );
-    connect( project(), TQT_SIGNAL(removedFilesFromProject(const TQStringList &)),
-             this, TQT_SLOT(removedFilesFromProject(const TQStringList &)) );
+    connect( project(), TQ_SIGNAL(addedFilesToProject(const TQStringList &)),
+             this, TQ_SLOT(addedFilesToProject(const TQStringList &)) );
+    connect( project(), TQ_SIGNAL(removedFilesFromProject(const TQStringList &)),
+             this, TQ_SLOT(removedFilesFromProject(const TQStringList &)) );
 
     if (!m_parser) {
        m_parser = new  PHPParser( this );
@@ -393,7 +393,7 @@ void PHPSupportPart::projectOpened()
 
     // We want to parse only after all components have been
     // properly initialized
-    TQTimer::singleShot(500, this, TQT_SLOT( initialParse() ) );
+    TQTimer::singleShot(500, this, TQ_SLOT( initialParse() ) );
 }
 
 void PHPSupportPart::initialParse( )
@@ -442,7 +442,7 @@ bool PHPSupportPart::parseProject()
    _jd->it = _jd->files.begin();
    _jd->dir.setPath( project()->projectDirectory() );
 
-   TQTimer::singleShot( 0, this, TQT_SLOT( slotParseFiles() ) );
+   TQTimer::singleShot( 0, this, TQ_SLOT( slotParseFiles() ) );
    return TRUE;
 }
 
@@ -470,7 +470,7 @@ void PHPSupportPart::slotParseFiles()
 
          ++( _jd->it );
       }
-      TQTimer::singleShot( 0, this, TQT_SLOT( slotParseFiles() ) );
+      TQTimer::singleShot( 0, this, TQ_SLOT( slotParseFiles() ) );
    }
    else // finished or interrupted
    {
