@@ -15,7 +15,7 @@
 #include "ctags2_selecttagfilebase.h"
 
 class SelectTagFile : public SelectTagFileBase {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -30,5 +30,3 @@ public slots:
 
 
 #endif
-
-// kate: space-indent off; indent-width 4; tab-width 4; show-tabs off;
