@@ -45,26 +45,26 @@ FileListWidget::FileListWidget(ProjectviewPart *part, TQWidget *parent)
 
 	setSelectionMode( TQListView::Extended );
 
-//	connect( _part->partController(), TQT_SIGNAL( partAdded(KParts::Part*) ), this, TQT_SLOT(partAdded(KParts::Part*)) );
-//	connect( _part->partController(), TQT_SIGNAL( partRemoved(KParts::Part*) ), this, TQT_SLOT(partRemoved()) );
-	connect( _part->partController(), TQT_SIGNAL( partAdded(KParts::Part*) ), this, TQT_SLOT(startRefreshTimer()) );
-	connect( _part->partController(), TQT_SIGNAL( partRemoved(KParts::Part*) ), this, TQT_SLOT(startRefreshTimer()) );
-	connect( _part->partController(), TQT_SIGNAL( activePartChanged(KParts::Part*) ), this, TQT_SLOT( activePartChanged(KParts::Part* )) );
+//	connect( _part->partController(), TQ_SIGNAL( partAdded(KParts::Part*) ), this, TQ_SLOT(partAdded(KParts::Part*)) );
+//	connect( _part->partController(), TQ_SIGNAL( partRemoved(KParts::Part*) ), this, TQ_SLOT(partRemoved()) );
+	connect( _part->partController(), TQ_SIGNAL( partAdded(KParts::Part*) ), this, TQ_SLOT(startRefreshTimer()) );
+	connect( _part->partController(), TQ_SIGNAL( partRemoved(KParts::Part*) ), this, TQ_SLOT(startRefreshTimer()) );
+	connect( _part->partController(), TQ_SIGNAL( activePartChanged(KParts::Part*) ), this, TQ_SLOT( activePartChanged(KParts::Part* )) );
 
-	connect( this, TQT_SIGNAL( executed( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
-	connect( this, TQT_SIGNAL( returnPressed( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( executed( TQListViewItem * ) ), this, TQ_SLOT( itemClicked( TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( returnPressed( TQListViewItem * ) ), this, TQ_SLOT( itemClicked( TQListViewItem * ) ) );
 
-	connect( this, TQT_SIGNAL( contextMenuRequested ( TQListViewItem *, const TQPoint & , int ) ),
-		this, TQT_SLOT( popupMenu(TQListViewItem *, const TQPoint & , int ) ) );
+	connect( this, TQ_SIGNAL( contextMenuRequested ( TQListViewItem *, const TQPoint & , int ) ),
+		this, TQ_SLOT( popupMenu(TQListViewItem *, const TQPoint & , int ) ) );
 
-	connect( _part->partController(), TQT_SIGNAL(documentChangedState(const KURL &, DocumentState)),
-		this, TQT_SLOT(documentChangedState(const KURL&, DocumentState )) );
+	connect( _part->partController(), TQ_SIGNAL(documentChangedState(const KURL &, DocumentState)),
+		this, TQ_SLOT(documentChangedState(const KURL&, DocumentState )) );
 
-	connect( _part->partController(), TQT_SIGNAL(partURLChanged(KParts::ReadOnlyPart * )), this, TQT_SLOT(refreshFileList()) );
+	connect( _part->partController(), TQ_SIGNAL(partURLChanged(KParts::ReadOnlyPart * )), this, TQ_SLOT(refreshFileList()) );
 
 	setItemMargin(10);
 	
-	connect( &m_refreshTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(refreshFileList()) );
+	connect( &m_refreshTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(refreshFileList()) );
 	
 	startRefreshTimer();
 }
@@ -226,9 +226,9 @@ void FileListWidget::popupMenu( TQListViewItem * item, const TQPoint & p, int )
 	{
 		TDEPopupMenu popup;
 		popup.insertTitle( i18n("File List") );
-		popup.insertItem( i18n("Close Selected"), this, TQT_SLOT(closeSelectedFiles()) );
-		popup.insertItem( i18n("Save Selected"), this, TQT_SLOT(saveSelectedFiles()) );
-		popup.insertItem( i18n("Reload Selected"), this, TQT_SLOT(reloadSelectedFiles()) );
+		popup.insertItem( i18n("Close Selected"), this, TQ_SLOT(closeSelectedFiles()) );
+		popup.insertItem( i18n("Save Selected"), this, TQ_SLOT(saveSelectedFiles()) );
+		popup.insertItem( i18n("Reload Selected"), this, TQ_SLOT(reloadSelectedFiles()) );
 
 		FileContext context( getSelectedURLs() );
         _part->core()->fillContextMenu( &popup, &context );
