@@ -178,44 +178,44 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 
         dirstack.setAutoDelete(true);
 
-	childproc = new TDEProcess(TQT_TQOBJECT(this));
+	childproc = new TDEProcess(this);
 	procLineMaker = new ProcessLineMaker( childproc );
 
-	connect( procLineMaker, TQT_SIGNAL(receivedStdoutLine(const TQCString&)),
-	         this, TQT_SLOT(insertStdoutLine(const TQCString&) ));
-	connect( procLineMaker, TQT_SIGNAL(receivedStderrLine(const TQCString&)),
-                 this, TQT_SLOT(insertStderrLine(const TQCString&) ));
-        connect( procLineMaker, TQT_SIGNAL(receivedPartialStdoutLine(const TQCString&)),
-                 this, TQT_SLOT(storePartialStdoutLine(const TQCString&) ));
-        connect( procLineMaker, TQT_SIGNAL(receivedPartialStderrLine(const TQCString&)),
-                 this, TQT_SLOT(storePartialStderrLine(const TQCString&) ));
+	connect( procLineMaker, TQ_SIGNAL(receivedStdoutLine(const TQCString&)),
+	         this, TQ_SLOT(insertStdoutLine(const TQCString&) ));
+	connect( procLineMaker, TQ_SIGNAL(receivedStderrLine(const TQCString&)),
+                 this, TQ_SLOT(insertStderrLine(const TQCString&) ));
+        connect( procLineMaker, TQ_SIGNAL(receivedPartialStdoutLine(const TQCString&)),
+                 this, TQ_SLOT(storePartialStdoutLine(const TQCString&) ));
+        connect( procLineMaker, TQ_SIGNAL(receivedPartialStderrLine(const TQCString&)),
+                 this, TQ_SLOT(storePartialStderrLine(const TQCString&) ));
 
-	connect( childproc, TQT_SIGNAL(processExited(TDEProcess*)),
-	         this, TQT_SLOT(slotProcessExited(TDEProcess*) )) ;
+	connect( childproc, TQ_SIGNAL(processExited(TDEProcess*)),
+	         this, TQ_SLOT(slotProcessExited(TDEProcess*) )) ;
 
-	connect( &m_directoryStatusFilter, TQT_SIGNAL(item(EnteringDirectoryItem*)),
-	         this, TQT_SLOT(slotEnteredDirectory(EnteringDirectoryItem*)) );
-	connect( &m_directoryStatusFilter, TQT_SIGNAL(item(ExitingDirectoryItem*)),
-	         this, TQT_SLOT(slotExitedDirectory(ExitingDirectoryItem*)) );
-	connect( &m_errorFilter, TQT_SIGNAL(item(MakeItem*)),
-	         this, TQT_SLOT(insertItem(MakeItem*)) );
-	connect( &m_actionFilter, TQT_SIGNAL(item(MakeItem*)),
-	         this, TQT_SLOT(insertItem(MakeItem*)) );
-	connect( &m_otherFilter, TQT_SIGNAL(item(MakeItem*)),
-	         this, TQT_SLOT(insertItem(MakeItem*)) );
+	connect( &m_directoryStatusFilter, TQ_SIGNAL(item(EnteringDirectoryItem*)),
+	         this, TQ_SLOT(slotEnteredDirectory(EnteringDirectoryItem*)) );
+	connect( &m_directoryStatusFilter, TQ_SIGNAL(item(ExitingDirectoryItem*)),
+	         this, TQ_SLOT(slotExitedDirectory(ExitingDirectoryItem*)) );
+	connect( &m_errorFilter, TQ_SIGNAL(item(MakeItem*)),
+	         this, TQ_SLOT(insertItem(MakeItem*)) );
+	connect( &m_actionFilter, TQ_SIGNAL(item(MakeItem*)),
+	         this, TQ_SLOT(insertItem(MakeItem*)) );
+	connect( &m_otherFilter, TQ_SIGNAL(item(MakeItem*)),
+	         this, TQ_SLOT(insertItem(MakeItem*)) );
 
-	connect( verticalScrollBar(), TQT_SIGNAL(sliderPressed()),
-	         this, TQT_SLOT(verticScrollingOn()) );
-	connect( verticalScrollBar(), TQT_SIGNAL(sliderReleased()),
-	         this, TQT_SLOT(verticScrollingOff()) );
-	connect( horizontalScrollBar(), TQT_SIGNAL(sliderPressed()),
-	         this, TQT_SLOT(horizScrollingOn()) );
-	connect( horizontalScrollBar(), TQT_SIGNAL(sliderReleased()),
-	         this, TQT_SLOT(horizScrollingOff()) );
+	connect( verticalScrollBar(), TQ_SIGNAL(sliderPressed()),
+	         this, TQ_SLOT(verticScrollingOn()) );
+	connect( verticalScrollBar(), TQ_SIGNAL(sliderReleased()),
+	         this, TQ_SLOT(verticScrollingOff()) );
+	connect( horizontalScrollBar(), TQ_SIGNAL(sliderPressed()),
+	         this, TQ_SLOT(horizScrollingOn()) );
+	connect( horizontalScrollBar(), TQ_SIGNAL(sliderReleased()),
+	         this, TQ_SLOT(horizScrollingOff()) );
 
 // this slot doesn't exist anymore
-// 	connect( m_part->partController(), TQT_SIGNAL(loadedFile(const KURL&)),
-// 	         this, TQT_SLOT(slotDocumentOpened(const KURL&)) );
+// 	connect( m_part->partController(), TQ_SIGNAL(loadedFile(const KURL&)),
+// 	         this, TQ_SLOT(slotDocumentOpened(const KURL&)) );
 }
 
 MakeWidget::~MakeWidget()
@@ -389,7 +389,7 @@ void MakeWidget::prevError()
 void MakeWidget::contentsMouseReleaseEvent( TQMouseEvent* e )
 {
 	TQTextEdit::contentsMouseReleaseEvent(e);
-	if ( e->button() != Qt::LeftButton )
+	if ( e->button() != TQt::LeftButton )
 		return;
 	searchItem(paragraphAt(e->pos()));
 }
@@ -588,7 +588,7 @@ void MakeWidget::slotProcessExited(TDEProcess *)
 	// and its TDEProcess object can be reused.
 	if (childproc->normalExit() && !childproc->exitStatus())
 	{
-		TQTimer::singleShot(0, this, TQT_SLOT(startNextJob()));
+		TQTimer::singleShot(0, this, TQ_SLOT(startNextJob()));
 // 		if (commandList.isEmpty())
 			// The last command on the list was successful so restore the
 			// output view to what it had before the compilation process started
@@ -698,23 +698,23 @@ TQPopupMenu* MakeWidget::createPopupMenu( const TQPoint& pos )
 	pMenu->setCheckable(true);
 
 	pMenu->insertSeparator();
-	int id = pMenu->insertItem(i18n("Line Wrapping"), this, TQT_SLOT(toggleLineWrapping()) );
+	int id = pMenu->insertItem(i18n("Line Wrapping"), this, TQ_SLOT(toggleLineWrapping()) );
 	pMenu->setItemChecked(id, m_bLineWrapping);
     pMenu->setWhatsThis(id, i18n("<b>Line wrapping</b><p>Enables or disables wrapping of command lines displayed."));
 
 	pMenu->insertSeparator();
-	id = pMenu->insertItem(i18n("Very Short Compiler Output"), this, TQT_SLOT(slotVeryShortCompilerOutput()) );
+	id = pMenu->insertItem(i18n("Very Short Compiler Output"), this, TQ_SLOT(slotVeryShortCompilerOutput()) );
     pMenu->setWhatsThis(id, i18n("<b>Very short compiler output</b><p>Displays only warnings, errors and the file names which are compiled."));
 	pMenu->setItemChecked(id, m_compilerOutputLevel == eVeryShort);
-	id = pMenu->insertItem(i18n("Short Compiler Output"), this, TQT_SLOT(slotShortCompilerOutput()) );
+	id = pMenu->insertItem(i18n("Short Compiler Output"), this, TQ_SLOT(slotShortCompilerOutput()) );
     pMenu->setWhatsThis(id, i18n("<b>Short compiler output</b><p>Suppresses all the compiler flags and formats to something readable."));
 	pMenu->setItemChecked(id, m_compilerOutputLevel == eShort);
-	id = pMenu->insertItem(i18n("Full Compiler Output"), this, TQT_SLOT(slotFullCompilerOutput()) );
+	id = pMenu->insertItem(i18n("Full Compiler Output"), this, TQ_SLOT(slotFullCompilerOutput()) );
     pMenu->setWhatsThis(id, i18n("<b>Full compiler output</b><p>Displays unmodified compiler output."));
 	pMenu->setItemChecked(id, m_compilerOutputLevel == eFull);
 
 	pMenu->insertSeparator();
-	id = pMenu->insertItem(i18n("Show Directory Navigation Messages"), this, TQT_SLOT(toggleShowDirNavigMessages()));
+	id = pMenu->insertItem(i18n("Show Directory Navigation Messages"), this, TQ_SLOT(toggleShowDirNavigMessages()));
     pMenu->setWhatsThis(id, i18n("<b>Show directory navigation messages</b><p>Shows <b>cd</b> commands that are executed while building."));
 	pMenu->setItemChecked(id, DirectoryItem::getShowDirectoryMessages());
 
