@@ -40,7 +40,7 @@ PartExplorerPlugin::PartExplorerPlugin(  TQObject *parent, const char *name, con
     m_widget = new PartExplorerForm( mainWindow()->main() );
 //    mainWindow()->embedSelectView( m_widget, i18n("PartExplorer"), i18n("Query system services"));
 
-    TDEAction *action = new TDEAction( i18n("&Part Explorer"), 0, this, TQT_SLOT(slotShowForm()),
+    TDEAction *action = new TDEAction( i18n("&Part Explorer"), 0, this, TQ_SLOT(slotShowForm()),
         actionCollection(), "show_partexplorerform" );
     action->setToolTip(i18n("TDETrader query execution"));
     action->setWhatsThis(i18n("<b>Part explorer</b><p>Shows a dialog for TDETrader query execution. Search your TDE documentation for more information about TDE services and TDETrader."));
