@@ -12,7 +12,7 @@
 
 void AddToolDialog::init()
 {
-    connect( tree, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(treeSelectionChanged(TQListViewItem*)) );
+    connect( tree, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this, TQ_SLOT(treeSelectionChanged(TQListViewItem*)) );
     tree->header()->hide();
 }
 
